แพ็คเกจนี้เป็นแพ็คเกจ Python ที่โชว์ข้อมูลเกียวกับ Willson Good”
================================================================

Link: https://www.youtube.com/channel/UCw0DXnAX7kh5j1c3We5ykzg/videos

PyPi: https://pypi.org/project/MynameisWillson/

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install MynameisWillson

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from MynameisWillson import Willson

   so = Willson()
   so.show_name()
   so.about()
   so.art()

พัฒนาโดย: Willson Good

YouTube: https://www.youtube.com/channel/UCw0DXnAX7kh5j1c3We5ykzg/videos
